pub struct SecretBool { /* private fields */ }Expand description
A secure boolean type that redacts its content in all display contexts and zeros its memory on drop
Implementations
Sourceimpl SecretBool
impl SecretBool
Sourcepub fn new_with_template(value: bool, template: String) -> Self
pub fn new_with_template(value: bool, template: String) -> Self
Create a new SecretBool with a custom redaction template
Sourcepub fn into_inner(self) -> bool
pub fn into_inner(self) -> bool
Convert back to a regular boolean (consumes the SecretBool)